totals(
x,
which = c("imputed", "fitted", "both"),
obs = FALSE,
level = NULL,
long = FALSE
)
Value
A data.frame with subclass trim.totals
(for pretty-printing). The columns are time, fitted
and se_fit (for standard error), and/or imputed
and se_imp, depending on the selection.
In case long=TRUE a long table is returned, and a different naming convention is used,
e.g., imputed/fitted info is in column series,
and standard error are always in column SE
Arguments
x
TRIM output structure (i.e., output of a call to trim)
which
(character) Select what totals to compute (see Details section).
obs
(logical) Flag to include total observations (or not).
level
(numeric) The confidence level required. If NULL, no confidence intervals are calculated.
long
(logical) Flag to return a tidy long table
Details
The idea of TRIM is to impute those site-time combinations where
no counts are available. Time-totals (i.e. summed over sites) can be obtained
for two cases:
"imputed": Time totals are computed after replacing missing values with values predicted by the model.
"fitted": Time totals are computed after replacing both missing values and observed values with
values predicted by the model.